@@ -1,3 +1,4 @@
+import time
 import jwt
 from jwt.exceptions import DecodeError
 import requests
@@ -15,6 +16,7 @@ class AtlantisClient:
     :param str url: Endereço da API do serviço Atlantis
     :param str client_id: ID do cliente cadastrado no Atlantis
     :param str client_secret: Secret do cliente cadastrado no Atlantis
+    :param bool skip_openid_configuration: Pula configuração do openid (Usado para ambiente de testes)
     """
     url = None
     client_id = None
@@ -25,6 +27,9 @@ class AtlantisClient:
         self.url = url.strip('/')
         self.client_id = client_id
         self.client_secret = client_secret
+        self._jwks = None
+        self._jwks_updated_at = 0
+        self._jwks_cache_seconds = 600
 
         if skip_openid_configuration:
             return
@@ -92,10 +97,15 @@ class AtlantisClient:
         :return: Chave(s) pública(s)
         :rtype: dict
         """
+        if self._jwks is not None and time.time() - self._jwks_updated_at < self._jwks_cache_seconds:
+            return self._jwks
+
         try:
             response = requests.get(self.configuration.get('jwks_uri'))
             response.raise_for_status()
-            return response.json()
+            self._jwks = response.json()
+            self._jwks_updated_at = time.time()
+            return self._jwks
         except HTTPError as error:
             raise AtlantisClientHTTPError(error) from error
 
