@@ -5,7 +5,9 @@ from stl_sdk.atlantis.client import AtlantisClient
 class AtlantisClientFlask(AtlantisClient):
     """Cliente Flask para comunicação com Atlantis.
         Ao iniciar o cliente ele irá buscar as variaveis de ambiente
-        `ATLANTIS_URL`, `ATLANTIS_CLIENT_ID` e `ATLANTIS_CLIENT_SECRET`
+        `ATLANTIS_URL`, `ATLANTIS_CLIENT_ID` e `ATLANTIS_CLIENT_SECRET`.
+
+        Para pular a chamada inicial de configuração do openId em seus teste, defina a variavel de ambiente `FLASK_ENV=testing`.
 
     Exemplo:
 
@@ -34,5 +36,6 @@ class AtlantisClientFlask(AtlantisClient):
         super().__init__(
             app.config['ATLANTIS_URL'],
             app.config['ATLANTIS_CLIENT_ID'],
-            client_secret=app.config.get('ATLANTIS_CLIENT_SECRET')
-        )
\ No newline at end of file
+            client_secret=app.config.get('ATLANTIS_CLIENT_SECRET'),
+            skip_openid_configuration=app.config.get('FLASK_ENV') == 'testing'
+        )
