@@ -6,13 +6,13 @@ from requests.exceptions import HTTPError
 class CoralClient:
     """Cliente HTTP para comunicação com Coral
 
-    :param str coral_url: Endereço da API do serviço Coral
+    :param str url: Endereço da API do serviço Coral
     :param str api_key: Chave de acesso a API
     :param str atlantis_client_id: Id do cliente que a chave de API foi emitida
     """
 
-    def __init__(self, coral_url, api_key, atlantis_client_id):
-        self.coral_url = coral_url.strip('/')
+    def __init__(self, url, api_key, atlantis_client_id):
+        self.url = url.strip('/')
         self.api_key = api_key
         self.atlantis_client_id = atlantis_client_id
 
@@ -47,7 +47,7 @@ class CoralClient:
         """
         try:
             response = requests.get(
-                    '{}/api/file'.format(self.coral_url),
+                    '{}/api/file'.format(self.url),
                     headers=self._get_headers(bucket, region=region),
                     params={
                         'key': key
@@ -62,13 +62,13 @@ class CoralClient:
 class CoralSyncClient(CoralClient):
     """Cliente HTTP para sincronização dos arquivos do banco de dados do Coral
 
-    :param str coral_url: Endereço da API do serviço Coral
+    :param str url: Endereço da API do serviço Coral
     :param str api_key: Chave de acesso a API
     :param str atlantis_client_id: Id do cliente que a chave de API foi emitida
     """
 
-    def __init__(self, coral_url, api_key, atlantis_client_id):
-        super().__init__(coral_url, api_key, atlantis_client_id)
+    def __init__(self, url, api_key, atlantis_client_id):
+        super().__init__(url, api_key, atlantis_client_id)
 
     def upsert_file(self, bucket, key, last_modified, size, metadata=None):
         """Crie ou atualiza um arquivo no banco do Coral.
@@ -98,7 +98,7 @@ class CoralSyncClient(CoralClient):
         """
         try:
             response = requests.post(
-                    '{}/api/sync'.format(self.coral_url),
+                    '{}/api/sync'.format(self.url),
                     headers=self._get_headers(bucket),
                     params={
                         'key': key
@@ -134,7 +134,7 @@ class CoralSyncClient(CoralClient):
         """
         try:
             response = requests.delete(
-                    '{}/api/sync'.format(self.coral_url),
+                    '{}/api/sync'.format(self.url),
                     headers=self._get_headers(bucket),
                     params={
                         'key': key
